@@ -6,7 +6,6 @@ import asyncio
 import dataclasses
 import re
 import struct
-import sys
 from collections import namedtuple
 from datetime import datetime
 from functools import partial
@@ -61,11 +60,6 @@ from .const import (
 )
 from .device_type import AirthingsDeviceType
 
-if sys.version_info[:2] < (3, 11):
-    from async_timeout import timeout as asyncio_timeout
-else:
-    from asyncio import timeout as asyncio_timeout
-
 Characteristic = namedtuple("Characteristic", ["uuid", "name", "format"])
 
 wave_gen_1_device_info_characteristics = [
@@ -867,7 +861,7 @@ class AirthingsBluetoothDeviceData:
                     DisconnectedError,
                     f"Disconnected from {client.address}",
                 ),
-                asyncio_timeout(UPDATE_TIMEOUT),
+                asyncio.timeout(UPDATE_TIMEOUT),
             ):
                 await self._get_device_characteristics(client, device)
                 await self._get_service_characteristics(client, device)
