@@ -5,7 +5,7 @@ from airthings_ble.parser import _decode_wave_radon
 _LOGGER = logging.getLogger(__name__)
 
 
-def test_wave_radon_sensor_data():
+def test_wave_radon_sensor_data() -> None:
     """Test wave plus sensor data."""
     raw_data = bytearray.fromhex("013860f009001100a709ffffffffffff0000ffff")
 
